@@ -40,7 +40,7 @@ from .basehandler import BaseHandler
 import atexit
 import glob
 
-__version__ = "0.3.3"
+__version__ = "0.3.4"
 _eureka_client = None
 _model_dict = None
 
@@ -294,7 +294,7 @@ class Server:
                 old_config = pickle.load(f)
                 for name, m in old_config.items():
 
-                    if self.get_start_tries(m) == "OK":
+                    if self.get_start_tries(m["model"]) == "OK":
                         try:
                             logger.info(f" * {name}")
                             newmodel = BaseHandler(
